@@ -1,42 +1,44 @@
 # coding=utf-8
-# Copyright 2013 Elsie Powell - embolalia.com
-# Licensed under the Eiffel Forum License 2.
+"""
+wikipedia.py - Sopel Wikipedia Module
+Copyright 2013 Elsie Powell - embolalia.com
+Licensed under the Eiffel Forum License 2.
+
+https://sopel.chat
+"""
 from __future__ import unicode_literals, absolute_import, print_function, division
 
-from sopel import tools
-from sopel.config.types import StaticSection, ValidatedAttribute
-from sopel.module import NOLIMIT, commands, example, rule
-from requests import get
 import re
 
-import sys
-if sys.version_info.major < 3:
-    from urllib import quote as _quote
-    from urlparse import unquote as _unquote
-    quote = lambda s: _quote(s.encode('utf-8')).decode('utf-8')
-    unquote = lambda s: _unquote(s.encode('utf-8')).decode('utf-8')
-else:
-    from urllib.parse import quote, unquote
+from requests import get
+
+from sopel.config.types import StaticSection, ValidatedAttribute
+from sopel.module import NOLIMIT, commands, example, url
+from sopel.tools.web import quote, unquote
+
 
 REDIRECT = re.compile(r'^REDIRECT (.*)')
+WIKIPEDIA_REGEX = r'/([a-z]+\.wikipedia\.org)/wiki/((?!File\:)[^ ]+)'
 
 
 class WikipediaSection(StaticSection):
     default_lang = ValidatedAttribute('default_lang', default='en')
-    """The default language to find articles from."""
+    """The default language to find articles from (same as Wikipedia language subdomain)."""
     lang_per_channel = ValidatedAttribute('lang_per_channel')
+    """List of ``#channel:langcode`` pairs to define Wikipedia language per channel."""
 
 
 def setup(bot):
     bot.config.define_section('wikipedia', WikipediaSection)
 
-    regex = re.compile('([a-z]+).(wikipedia.org/wiki/)([^ ]+)')
-    if not bot.memory.contains('url_callbacks'):
-        bot.memory['url_callbacks'] = tools.SopelMemory()
-    bot.memory['url_callbacks'][regex] = mw_info
-
 
 def configure(config):
+    """
+    | name | example | purpose |
+    | ---- | ------- | ------- |
+    | default\\_lang | en | The default language to find articles from (same as Wikipedia language subdomain) |
+    | lang\\_per\\_channel | #YourPants:en,#TusPantalones:es | List of #channel:langcode pairs to define Wikipedia language per channel |
+    """
     config.define_section('wikipedia', WikipediaSection)
     config.wikipedia.configure_setting(
         'default_lang',
@@ -45,11 +47,12 @@ def configure(config):
 
 
 def mw_search(server, query, num):
-    """
+    """Search a MediaWiki site
+
     Searches the specified MediaWiki server for the given query, and returns
     the specified number of results.
     """
-    search_url = ('http://%s/w/api.php?format=json&action=query'
+    search_url = ('https://%s/w/api.php?format=json&action=query'
                   '&list=search&srlimit=%d&srprop=timestamp&srwhat=text'
                   '&srsearch=') % (server, num)
     search_url += query
@@ -57,8 +60,7 @@ def mw_search(server, query, num):
     if 'query' in query:
         query = query['query']['search']
         return [r['title'] for r in query]
-    else:
-        return None
+    return None
 
 
 def say_snippet(bot, trigger, server, query, show_url=True):
@@ -80,10 +82,7 @@ def say_snippet(bot, trigger, server, query, show_url=True):
 
 
 def mw_snippet(server, query):
-    """
-    Retrives a snippet of the specified length from the given page on the given
-    server.
-    """
+    """Retrieves a snippet of the given page from the given MediaWiki server."""
     snippet_url = ('https://' + server + '/w/api.php?format=json'
                    '&action=query&prop=extracts&exintro&explaintext'
                    '&exchars=300&redirects&titles=')
@@ -98,13 +97,9 @@ def mw_snippet(server, query):
     return snippet['extract']
 
 
-@rule('.*\/([a-z]+\.wikipedia\.org)\/wiki\/((?!File\:)[^ ]+).*')
-def mw_info(bot, trigger, found_match=None):
-    """
-    Retrives a snippet of the specified length from the given page on the given
-    server.
-    """
-    match = found_match or trigger
+@url(WIKIPEDIA_REGEX)
+def mw_info(bot, trigger, match):
+    """Retrieves and outputs a snippet from the linked page."""
     say_snippet(bot, trigger, match.group(1), unquote(match.group(2)), show_url=False)
 
 
@@ -116,7 +111,7 @@ def wikipedia(bot, trigger):
     # change lang if channel has custom language set
     if (trigger.sender and not trigger.sender.is_nick() and
             bot.config.wikipedia.lang_per_channel):
-        customlang = re.search('(' + trigger.sender + '):(\w+)',
+        customlang = re.search('(' + trigger.sender + r'):(\w+)',
                                bot.config.wikipedia.lang_per_channel)
         if customlang is not None:
             lang = customlang.group(2)
